@@ -646,7 +646,7 @@ class AwsSeePy:
         role         = os.environ['AWS_ROLE'] if 'AWS_ROLE' in os.environ else ""
         tokenNeeded  = os.environ['AWS_WITH_TOKEN'] if 'AWS_WITH_TOKEN' in os.environ else ""
 
-        if not account or account == "" and profile and profile != "":
+        if (not account or account == "") and (profile and profile.strip() != ""):
             credential = self.credentialsRepository.findByProfile(profile)
             account = credential["account"]
 
