@@ -101,12 +101,13 @@ class SessionManager:
         if Utils.isWindows():
             terminalCommand            = self.preferences.windows.terminalCommand
             sessionInfo.setBashEnv     = False
-            outputWin, environmentsWin = self.createEnvironment(sessionInfo)
-            output = outputWin
             
             # Check if there's a Terminal Commmand Set
             if AwsSeeState.NEW_TERMINAL:
                 if not terminalCommand or terminalCommand.lstrip().rstrip() == "":
+                    outputWin, environmentsWin = self.createEnvironment(sessionInfo)
+                    output = outputWin
+
                     # Check CMDER is installed (then use it)
                     if which("cmder") and os.environ['CMDER_ROOT'] != "":
                         os.system(f"start %CMDER_ROOT%\\vendor\\conemu-maximus5\\ConEmu.exe /icon \"%CMDER_ROOT%\\cmder.exe\" /title \"{windowTitle}\" /loadcfgfile \"%CMDER_ROOT%\\config\\ConEmu.xml\" /cmd cmd /k " + environmentsWin)
@@ -122,21 +123,16 @@ class SessionManager:
                             return None, None
                 else:
                     if "git-bash.exe" in terminalCommand or "sh.exe" in terminalCommand:
-                        sessionInfo.setBashEnv = True
-                        outputBash, environmentsBash = self.createEnvironment(sessionInfo)
+                        sessionInfo.setBashEnv             = True
+                        sessionInfo.setRunGitBashOnWindows = True  #To ask to set the path harcoded to the external scripts ~/.awsee/... otherwise it wont't find C:\User\...  when open the Shell Window
+                        outputBash, environmentsBash       = self.createEnvironment(sessionInfo)
                         output = outputBash
 
-                        # Regarding the place where Python is running (not the Target Console to Open, configured at awsee.ini)...  
-                        # Check if the Call to open a Shell Script Terminal were made inside a GitBash, if not... change to Windows Style (the Output Python window)
-                        if not Utils.isRunningOnGitBash():
-                            outputWin, _ = self.createEnvironment(sessionInfo)
-                            output = outputWin
-
                         os_command = ""
                         if "git-bash.exe" in terminalCommand:
-                            os_command = f"start {terminalCommand} --needs-console --no-hide --command=usr\\bin\\bash.exe --login -i -c \"sh -c 'source ./{environmentsBash}; exec sh'\""
+                            os_command = f"start {terminalCommand} --needs-console --no-hide --command=usr\\bin\\bash.exe --login -i -c \"sh -c 'source {environmentsBash}; exec sh'\""
                         elif "sh.exe" in terminalCommand:
-                            os_command = f"start {terminalCommand} --login -i -l -c \"sh -c 'source ./{environmentsBash}; exec sh'\""
+                            os_command = f"start {terminalCommand} --login -i -l -c \"sh -c 'source {environmentsBash}; exec sh'\""
                         else:
                             msg = f"""\n{Style.GREEN}    Please check the {Style.IBLUE}terminal-command{Style.GREEN} set at your {Style.IBLUE}~/.awsee/awsee.ini{Style.GREEN}, WINDOWS section in order \n    to open a Terminal ready to use with your AWS Session Token configured.
                             \n    Example: \n    {Style.IBLUE}[WINDOWS]\n    terminal-command = {Style.IGREEN}d:\Program Files\Git\sh.exe{Style.RESET}"""
@@ -144,8 +140,21 @@ class SessionManager:
                             return None, None
                         os.system(os_command)
                     elif "wt" in terminalCommand:
+                        outputWin, environmentsWin = self.createEnvironment(sessionInfo)
+                        output = outputWin
                         os.system("wt -d c:\ cmd /k " + environmentsWin)
 
+            else:
+                # Windows (Where Am I? CMD/CDMER or GitBash (analysing the present of environment variable SHELL, if it there, so it is GitBash))
+                if Utils.isRunningOnGitBash():
+                    sessionInfo.setBashEnv       = True
+                    outputBash, environmentsBash = self.createEnvironment(sessionInfo)
+                    output = outputBash
+                else:
+                    sessionInfo.setBashEnv     = False
+                    outputWin, environmentsWin = self.createEnvironment(sessionInfo)
+                    output = outputWin
+
         else:
             # LINUX
             terminalCommand                = self.preferences.linux.terminalCommand
@@ -217,10 +226,19 @@ rm {self.SCRIPTS_PREFIX_NAME_FILE}*
         environments     = ""
         if AwsSeeState.NEW_TERMINAL:
             initFileContent  = self.createContentScriptFileStartSession(sessionInfo)
-            completePathFile = os.path.join(TEMP_CACHE_FOLDER, sessionInfo.scriptFile)
-            with open(f"{completePathFile}",'w') as fout:
+
+            with open(f"{os.path.join(TEMP_CACHE_FOLDER, sessionInfo.scriptFile)}",'w') as fout:
                 fout.write(initFileContent)
-            environments = f"\"{completePathFile}\""
+
+            if sessionInfo.runGitBashOnWindows:
+                #To ask to set the path of the external scripts to ~/.awsee/... (even though launched from CMDER) otherwise it wont't find C:\User\...  when open the Shell Window
+                completePathFile = "~/.awsee/tmp/" + sessionInfo.scriptFile
+                environments = completePathFile
+            else:
+                # Get the default format where it is running Shell or Windows
+                completePathFile = os.path.join(TEMP_CACHE_FOLDER, sessionInfo.scriptFile)
+                environments = f"\"{completePathFile}\""
+
             self.createCleanEnvironmentScript(completePathFile)
         return output, environments
 
@@ -244,7 +262,6 @@ rm {self.SCRIPTS_PREFIX_NAME_FILE}*
         if sessionInfo.isBashEnv:
             commandEnvSet = "export"
             executeScript = f"{sessionInfo.scriptFileBash}"
-            
 
         diffLabel = self.calculateExpiresTime(sessionInfo.expiration)
 
@@ -394,18 +411,21 @@ rm {self.SCRIPTS_PREFIX_NAME_FILE}*
             os.makedirs(aliasPath)
         
         aliasFile = os.path.join(aliasPath,"alias_awsee.txt")
-        if Utils.isWindows():
-            with open(aliasFile,'w') as fout:
-                fout.write("DOSKEY info=awsee -i\n")
-                fout.write("DOSKEY s3=aws s3 ls\n")
-                fout.write("DOSKEY ssmec2=aws ssm start-session --target \"i-\"\n")
-                fout.write("DOSKEY ec2=aws ec2 describe-instances --query Reservations[*].Instances[*].InstanceId --output table\n")
-        else:
-            with open(aliasFile,'w') as fout:
-                fout.write("alias s3='aws s3 ls'\n")
-                fout.write("alias info='awsee -i'\n")
-                fout.write("alias info='aws ssm start-session --target \"i-\"'\n")
-                fout.write("alias ec2='aws ec2 describe-instances --query Reservations[*].Instances[*].InstanceId --output table'\n")
+        if not os.path.exists(aliasFile):
+            if Utils.isWindows():
+                with open(aliasFile,'w') as fout:
+                    fout.write("DOSKEY info=awsee -i\n")
+                    fout.write("DOSKEY s3=aws s3 ls\n")
+                    fout.write("DOSKEY ssmec2=aws ssm start-session --target \"i-\"\n")
+                    fout.write("DOSKEY ec2=aws ec2 describe-instances --query Reservations[*].Instances[*].InstanceId --output table\n")
+                    fout.write("DOSKEY calleridentity=aws sts get-caller-identity --output table\n")
+            else:
+                with open(aliasFile,'w') as fout:
+                    fout.write("alias s3='aws s3 ls'\n")
+                    fout.write("alias info='awsee -i'\n")
+                    fout.write("alias info='aws ssm start-session --target \"i-\"'\n")
+                    fout.write("alias ec2='aws ec2 describe-instances --query Reservations[*].Instances[*].InstanceId --output table'\n")
+                    fout.write("alias calleridentity='aws sts get-caller-identity --output table'\n")
     
     def getAliasFileContent(self):
         aliasPath = os.path.join(expanduser("~"),".awsee","alias")
@@ -426,7 +446,9 @@ rm {self.SCRIPTS_PREFIX_NAME_FILE}*
         os.environ["AWS_SEE"] = uuidStr
         sessionInfo.uuid = uuidStr
 
-        command = "SET" if Utils.isWindows() else "export"
+        command = "SET" 
+        if sessionInfo.isBashEnv:
+           command = "export"
 
         self.cleanAwsSession(False)
 
